==> elgg1.2.tar.gz: elgg1.2/mod/bookmarks/languages/en.php <==
<?php

	$english = array(
	
		/**
		 * Menu items and titles
		 */
	
			'bookmarks' => "Bookmarks",
			'bookmarks:add' => "Bookmark something",
			'bookmarks:read' => "Bookmarked items",
			'bookmarks:friends' => "Friends' bookmarks",
			'bookmarks:everyone' => "All site bookmarks",
			'bookmarks:this' => "Bookmark this",
			'bookmarks:bookmarklet' => "Get bookmarklet",
			'bookmarks:inbox' => "Bookmarks inbox",
			'bookmarks:more' => "More bookmarks",
			'bookmarks:shareditem' => "Bookmarked item",
			'bookmarks:with' => "Share with",
	
			'bookmarks:address' => "Address of the resource to bookmark",
	
			'bookmarks:delete:confirm' => "Are you sure you want to delete this resource?",
	
			'bookmarks:numbertodisplay' => 'Number of bookmarked items to display',
	
			'bookmarks:shared' => "Bookmarked",
			'bookmarks:visit' => "Visit resource",
			'bookmarks:recent' => "Recent bookmarks",
	
			'bookmarks:river:created' => '%s bookmarked',
			'bookmarks:river:annotate' => '%s commented on',
			'bookmarks:river:item' => 'an item',
	
			'item:object:bookmarks' => 'Bookmarked items',
	
	
		/**
		 * More text
		 */
		    
		    'bookmarks:widget:description' => 
		            "This widget is designed for your dashboard and will show you the latest items in your bookmarks inbox.",
	
			'bookmarks:bookmarklet:description' =>
					"The bookmarks bookmarklet allows you to share any resource you find on the web with your friends, or just bookmark it for yourself. To use it, simply drag the following button to your browser's links bar:",

	        'bookmarks:bookmarklet:descriptionie' =>
					"If you are using Internet Explorer, you will need to right click on the bookmarklet icon, select 'add to favorites', and then the Links bar.",

			'bookmarks:bookmarklet:description:conclusion' =>
					"You can then save any page you visit by clicking it at any time.",
	
		/**
		 * Status messages
		 */
	
			'bookmarks:save:success' => "Your item was successfully bookmarked.",
			'bookmarks:delete:success' => "Your bookmarked item was successfully deleted.",
	
		/**
		 * Error messages
		 */
	
			'bookmarks:save:failed' => "Your bookmarked item could not be saved. Please try again.",
			'bookmarks:delete:failed' => "Your bookmarked item could not be deleted. Please try again.",
	
	
	);
					
	add_translation("en",$english);

?>

==> elgg1.5.tar.gz: elgg1.5/mod/bookmarks/languages/en.php <==
<?php

	$english = array(
	
		/**
		 * Menu items and titles
		 */
	
			'bookmarks' => "Bookmarks",
			'bookmarks:add' => "Bookmark something",
			'bookmarks:read' => "Bookmarked items",
			'bookmarks:friends' => "Friends' bookmarks",
			'bookmarks:everyone' => "All site bookmarks",
			'bookmarks:this' => "Bookmark this",
			'bookmarks:bookmarklet' => "Get bookmarklet",
			'bookmarks:inbox' => "Bookmarks inbox",
			'bookmarks:more' => "More",
			'bookmarks:shareditem' => "Bookmarked item",
			'bookmarks:with' => "Share with",
			'bookmarks:new' => "A new bookmarked item",
			'bookmarks:via' => "via bookmarks",
			'bookmarks:address' => "Address of the resource to bookmark",
	
			'bookmarks:delete:confirm' => "Are you sure you want to delete this resource?",
	
			'bookmarks:numbertodisplay' => 'Number of bookmarked items to display',
	
			'bookmarks:shared' => "Bookmarked",
			'bookmarks:visit' => "Visit resource",
			'bookmarks:recent' => "Recent bookmarks",
	
			'bookmarks:river:created' => '%s bookmarked',
			'bookmarks:river:annotate' => 'posted a comment on this bookmarked item',
			'bookmarks:river:item' => 'an item',
	
			'item:object:bookmarks' => 'Bookmarked items',
	
	
		/**
		 * More text
		 */
		    
		    'bookmarks:widget:description' => 
		            "This widget is designed for your dashboard and will show you the latest items in your bookmarks inbox.",
	
			'bookmarks:bookmarklet:description' =>
					"The bookmarks bookmarklet allows you to share any resource you find on the web with your friends, or just bookmark it for yourself. To use it, simply drag the following button to your browser's links bar:",

	        'bookmarks:bookmarklet:descriptionie' =>
					"If you are using Internet Explorer, you will need to right click on the bookmarklet icon, select 'add to favorites', and then the Links bar.",

			'bookmarks:bookmarklet:description:conclusion' =>
					"You can then save any page you visit by clicking it at any time.",
	
		/**
		 * Status messages
		 */
	
			'bookmarks:save:success' => "Your item was successfully bookmarked.",
			'bookmarks:delete:success' => "Your bookmarked item was successfully deleted.",
	
		/**
		 * Error messages
		 */
	
			'bookmarks:save:failed' => "Your bookmarked item could not be saved. Please try again.",
			'bookmarks:delete:failed' => "Your bookmarked item could not be deleted. Please try again.",
	
	
	);
					
	add_translation("en",$english);

?>
